# lvmguider

![Versions](https://img.shields.io/badge/python->3.10-blue)
[![Test](https://github.com/sdss/lvmguider/actions/workflows/test.yml/badge.svg)](https://github.com/sdss/lvmguider/actions/workflows/test.yml)

<!-- [![Documentation Status](https://readthedocs.org/projects/lvmguider/badge/?version=latest)](https://lvmguider.readthedocs.io/en/latest/) -->
<!-- [![codecov](https://codecov.io/gh/sdss/lvmguider/branch/main/graph/badge.svg)](https://codecov.io/gh/sdss/lvmguider) -->

A package for LVM guiding and focusing.
